# src/kallisto/data/vdw.py
# Scaling factors to match vdw radii from Table 12
# in J. Phys. Chem. A, Vol. 113, No. 19, 2009
truhlar = {
    "H": 0.65,
    "He": 1.00,
    "Li": 0.65,
    "Be": 0.67,
    "B": 0.92,
    "C": 0.89,
    "N": 0.87,
    "O": 0.89,
    "F": 0.91,
    "Ne": 1.00,
    "Na": 0.81,
    "Mg": 0.69,
    "Al": 0.76,
    "Si": 0.93,
    "P": 0.84,
    "S": 0.87,
    "Cl": 0.89,
    "Ar": 1.00,
    "K": 0.88,
    "Ca": 0.83,
    # Sc-Zn
    # interpolated wrt Z
    # Start: Ca factor
    # End:   Ga factor
    "Sc": 0.82,
    "Ti": 0.82,
    "V": 0.82,
    "Cr": 0.81,
    "Mn": 0.81,
    "Fe": 0.80,
    "Co": 0.80,
    "Ni": 0.79,
    "Cu": 0.79,
    "Zn": 0.79,
    #
    "Ga": 0.78,
    "Ge": 0.92,
    "As": 0.84,
    "Se": 0.89,
    "Br": 0.88,
    "Kr": 1.00,
    "Rb": 0.96,
    "Sr": 0.86,
    # Y-Cd
    # interpolated wrt Z
    # Start: Sr factor
    # End:   In factor
    "Y": 0.86,
    "Zr": 0.85,
    "Nb": 0.84,
    "Mo": 0.83,
    "Tc": 0.83,
    "Ru": 0.82,
    "Rh": 0.81,
    "Pd": 0.80,
    "Ag": 0.79,
    "Cd": 0.79,
    #
    "In": 0.78,
    "Sn": 0.90,
    "Sb": 0.89,
    "Te": 0.91,
    "I": 0.90,
    "Xe": 1.00,
    "Cs": 1.04,
    "Ba": 0.89,
    "La": 0.87,
    # do not scale lanthanoids
    "Ce": 1.00,
    "Pr": 1.00,
    "Nd": 1.00,
    "Pm": 1.00,
    "Sm": 1.00,
    "Eu": 1.00,
    "Gd": 1.00,
    "Tb": 1.00,
    "Dy": 1.00,
    "Ho": 1.00,
    "Er": 1.00,
    "Tm": 1.00,
    "Yb": 1.00,
    "Lu": 1.00,
    # Hf-Hg
    # interpolated wrt Z
    # Start: Ba factor
    # End:   Tl factor
    "Hf": 0.87,
    "Ta": 0.86,
    "W": 0.85,
    "Re": 0.84,
    "Os": 0.83,
    "Ir": 0.82,
    "Pt": 0.81,
    "Au": 0.81,
    "Hg": 0.80,
    #
    "Tl": 0.79,
    "Pb": 0.83,
    "Bi": 0.88,
    "Po": 0.85,
    "At": 0.89,
    "Rn": 1.00,
}

# Scaling factors to match vdw radii
# in Chem. Eur. J. 2017, 23, 4017
rahm = {
    "H": 0.91,
    "He": 0.95,
    "Li": 0.80,
    "Be": 0.95,
    "B": 0.98,
    "C": 0.99,
    "N": 1.00,
    "O": 1.00,
    "F": 1.00,
    "Ne": 1.00,
    "Na": 0.79,
    "Mg": 0.96,
    "Al": 0.99,
    "Si": 1.02,
    "P": 1.04,
    "S": 1.04,
    "Cl": 1.05,
    "Ar": 1.04,
    "K": 0.75,
    "Ca": 0.97,
    "Sc": 0.98,
    "Ti": 0.97,
    "V": 0.97,
    "Cr": 0.92,
    "Mn": 0.96,
    "Fe": 0.97,
    "Co": 0.96,
    "Ni": 0.94,
    "Cu": 0.92,
    "Zn": 0.96,
    "Ga": 0.97,
    "Ge": 1.03,
    "As": 1.05,
    "Se": 1.05,
    "Br": 1.06,
    "Kr": 1.05,
    "Rb": 0.76,
    "Sr": 0.97,
    "Y": 0.99,
    "Zr": 1.00,
    "Nb": 0.95,
    "Mo": 0.97,
    "Tc": 0.98,
    "Ru": 0.97,
    "Rh": 0.95,
    "Pd": 0.88,
    "Ag": 0.95,
    "Cd": 1.00,
    "In": 0.99,
    "Sn": 1.03,
    "Sb": 1.07,
    "Te": 1.07,
    "I": 1.08,
    "Xe": 1.08,
    "Cs": 0.76,
    "Ba": 0.97,
    "La": 0.98,
    "Ce": 1.21,
    "Pr": 0.97,
    "Nd": 0.97,
    "Pm": 0.98,
    "Sm": 0.97,
    "Eu": 0.98,
    "Gd": 1.01,
    "Tb": 0.95,
    "Dy": 0.94,
    "Ho": 0.97,
    "Er": 0.97,
    "Tm": 0.97,
    "Yb": 1.00,
    "Lu": 1.00,
    "Hf": 1.01,
    "Ta": 1.01,
    "W": 1.02,
    "Re": 1.01,
    "Os": 1.01,
    "Ir": 1.02,
    "Pt": 1.01,
    "Au": 1.00,
    "Hg": 1.02,
    "Tl": 0.97,
    "Pb": 1.02,
    "Bi": 1.06,
    "Po": 1.08,
    "At": 1.09,
    "Rn": 1.09,
}
